@@ -11,8 +11,10 @@
 #' logistic regression (\code{"logistic"}), Poisson regression
 #' (\code{"poisson"}), Weibull (\code{"weibull"}) and Cox regression
 #' for time to event data (\code{"coxph"}),
-#' and Cox models for competing risks data (\code{"compet"}). For the latter, a
-#' Cox model is assumed for each cause of failure, and the event indicator
+#' and Cox models for competing risks data (\code{"compet"}). For \code{"coxph"},
+#' the event indicator should be integer coded with 0 for censoring and 1 for event.
+#' For \code{"compet"}, a Cox model is assumed for each cause specific hazard function,
+#' and the event indicator
 #' should be integer coded with 0 corresponding to censoring, 1 corresponding to
 #' failure from the first cause etc.
 #'
@@ -99,9 +101,8 @@
 #' @references Bartlett JW, Seaman SR, White IR, Carpenter JR. Multiple imputation of covariates
 #' by fully conditional specification: accommodating the substantive model. Statistical Methods
 #' in Medical Research 2015; 24(4): 462-487. \doi{10.1177/0962280214521348}
-
 #' @import stats
-
+#' @importFrom survival Surv
 #' @export
 smcfcs <- function(originaldata,smtype,smformula,method,predictorMatrix=NULL,m=5,numit=10,rjlimit=1000,noisy=FALSE,errorProneMatrix=NULL) {
   #call core  smcfcs function, passing through arguments
@@ -223,8 +224,11 @@ smcfcs.core <- function(originaldata,smtype,smformula,method,predictorMatrix=NUL
     dCol <- (1:dim(originaldata)[2])[colnames(originaldata) %in% toString(as.formula(smformula)[[2]][[3]])]
     outcomeCol <- c(timeCol, dCol)
     d <- originaldata[,dCol]
+    if (!(identical(unique(d),c(0,1))) & !(identical(unique(d),1))) {
+      stop("Event indicator for coxph must be coded 0/1 for censoring/event.")
+    }
 
-    nullMod <- survival::coxph(Surv(originaldata[,timeCol],originaldata[,dCol])~1,
+    nullMod <- survival::coxph(survival::Surv(originaldata[,timeCol],originaldata[,dCol])~1,
                                control = survival::coxph.control(timefix = FALSE))
     basehaz <- survival::basehaz(nullMod)
     H0indices <- match(originaldata[,timeCol], basehaz[,2])
@@ -1081,7 +1085,8 @@ smcfcs.core <- function(originaldata,smtype,smformula,method,predictorMatrix=NUL
   res <- list(
     impDatasets = imputations,
     smCoefIter = smCoefIter,
-    smInfo = list("smtype" = smtype, "smformula" = smformula)
+    smInfo = list("smtype" = smtype, "smformula" = smformula),
+    extraArgs = extraArgs # For plot of dtsam
   )
   class(res) <- "smcfcs"
 
